@@ -4,19 +4,12 @@ import cooptools.geometry as geo
 from coopstructs.geometry.line import Line
 from scipy.spatial import ConvexHull
 from shapely.geometry import Polygon, Point
+from .exceptions import DuplicatePointException
+from .logger import geoLogger
+from cooptools.common import all_indxs_in_lst
 
 
-def all_indxs_in_lst(lst: List, value) -> List[int]:
-    idxs = []
-    idx = -1
-    while True:
-        try:
-            idx = lst.index(value, idx + 1)
-            idxs.append(idx)
-        except ValueError as e:
-            break
-
-    return idxs
+DUMMY_NEXT_ZONE_NAME = "DUMMY"
 
 class PolygonRegion:
 
@@ -55,28 +48,25 @@ class PolygonRegion:
         # valid if at least 3 points and they are not collinear
         return len(self.boundary_points) >= 3 and not geo.collinear_points([point.as_tuple() for point in self.boundary_points])
 
-    def add_points_between_points(self, points: Dict[Vector2, Tuple[int, int]]):
-        for point, between_idxs in points.items():
-
-            i0, i1 = between_idxs
-
-            # raise if not consecutive points (index dif should be 1 or len of list for rollover)
-            if abs(i1 - i0) != 1 and abs(i1 - i0) != len(self.boundary_points):
-                raise ValueError(f"The provided bounding points for point {point} are not at sequential indexes on the boundary [{i0}] and [{i1}]")
-
-            # add point between provided between points
-            if abs(i1 - i0) == 1:
-                self.boundary_points.insert(min(i0, i1) + 1, point)
-            elif abs(i1 - i0) == len(self.boundary_points):
-                self.boundary_points.append(point)
-
     def add_points(self, points: List[Vector2], at_idx: int = None):
+        # check if the new point(s) to be added are a duplicate of the last point added
+        bndry_pts_init = self.boundary_points and len(self.boundary_points) > 0
+        if bndry_pts_init \
+                and at_idx \
+                and points[0] in self.boundary_points[at_idx-1: at_idx + 1]:
+            raise DuplicatePointException(points[0])
+        elif bndry_pts_init \
+                and points[0] == self.boundary_points[-1]:
+            raise DuplicatePointException(points[0])
+
 
         if at_idx is None:
             self.boundary_points += points
         else:
             self.boundary_points[at_idx:at_idx] = points
 
+        geoLogger.info(f'Points {points} added at idx: {at_idx}')
+
     def remove_point(self):
         if len(self.boundary_points) > 0:
             self.boundary_points.pop(-1)
@@ -123,15 +113,15 @@ class PolygonRegion:
     def with_additional_point(self,
                               point: Vector2,
                               convex: bool = False,
-                              between_idxs: Tuple[int, int] = None):
+                              at_idx: int = None):
 
         new_list = self.boundary_points + [point]
 
         if convex:
             poly = PolygonRegion.convex_hull(new_list)
-        elif between_idxs is not None:
+        elif at_idx is not None:
             poly = PolygonRegion(boundary_points=self.boundary_points)
-            poly.add_points_between_points({point: between_idxs})
+            poly.add_points([point], at_idx)
         else:
             poly = PolygonRegion(boundary_points=new_list)
 
@@ -177,6 +167,6 @@ if __name__ == "__main__":
     new = Vector2(11, 4)
     bnds = poly.insersection_boundary_idxs_from_origin(new, Vector2(5, 5))
 
-    poly2 = poly.with_additional_point(new, between_idxs=bnds[0])
+    poly2 = poly.with_additional_point(new, at_idx=bnds[0])
     print(poly2)
 
